<p align="center">
    <a href="https://k15z.github.io/EchoFlow">
        <img width=760 src="docs/assets/header-dark.png">
    </a>
</p>

<p align="center">
    <a href="https://github.com/k15z/echoflow/actions"><img src="https://github.com/k15z/echoflow/workflows/Build%20Main/badge.svg"></a>
    <a href="https://k15z.github.io/EchoFlow"><img src="https://github.com/k15z/echoflow/workflows/Documentation/badge.svg"></a>
    <a href="https://codecov.io/gh/k15z/echoflow"><img src="https://codecov.io/gh/k15z/echoflow/branch/main/graph/badge.svg"></a>
</p>

---
This library provides tools for generative modeling of tabular datasets using 
normalizing flows. Some of it's features include:

* Density estimation.
* Joint + conditional sampling.
* Categorical + continuous values.
* Normalizing flows from RealNVP and MADE.

To get started with EchoFlow, check out our documentation [here](https://k15z.github.io/EchoFlow)! Or, learn more about this project from our blog post [here](https://kevz.dev/echoflow/).
